==> haskell-slist-0.2.1.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-slist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 slist
version:              0.2.1.0
visibility:           public
id:                   slist-0.2.1.0-BXvJfqctCV930ezrBkRt0o
key:                  slist-0.2.1.0-BXvJfqctCV930ezrBkRt0o
license:              MPL-2.0
copyright:
    2019-2020 Veronika Romashkina
    2020-2022 Kowainik

maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina
homepage:             https://github.com/kowainik/slist
synopsis:             Sized list
description:
    This package implements @Slist@ data structure that stores the size
    of the list along with the list itself.

category:             Data Structures, List
abi:                  aff18dc2e50b22dca52e106792147ffd
exposed:              True
exposed-modules:
    Slist Slist.Containers Slist.Maybe Slist.Size Slist.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-slist
hs-libraries:         HSslist-0.2.1.0-BXvJfqctCV930ezrBkRt0o
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-slist/html/slist.haddock
haddock-html:         /usr/share/doc/haskell-slist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-slist-0.2.1.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-slist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 slist
version:              0.2.1.0
visibility:           public
id:                   slist-0.2.1.0-44niU0WazbK7PEBCAnPTHZ
key:                  slist-0.2.1.0-44niU0WazbK7PEBCAnPTHZ
license:              MPL-2.0
copyright:
    2019-2020 Veronika Romashkina
    2020-2022 Kowainik

maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina
homepage:             https://github.com/kowainik/slist
synopsis:             Sized list
description:
    This package implements @Slist@ data structure that stores the size
    of the list along with the list itself.

category:             Data Structures, List
abi:                  11f772ce661e3302b2130cb0625bceb5
exposed:              True
exposed-modules:
    Slist Slist.Containers Slist.Maybe Slist.Size Slist.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-slist
hs-libraries:         HSslist-0.2.1.0-44niU0WazbK7PEBCAnPTHZ
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-slist/html/slist.haddock
haddock-html:         /usr/share/doc/haskell-slist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
